Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Kinesis Data Streams.

Actions, resources, and condition keys for Amazon Kinesis Data Streams - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Kinesis Data Streams

Amazon Kinesis Data Streams (service prefix: `kinesis` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Kinesis Data Streams
- Resource types defined by Amazon Kinesis Data Streams
- Condition keys for Amazon Kinesis Data Streams

## Actions defined by Amazon Kinesis Data Streams

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTagsToStream | Grants permission to add or update tags for the specified Amazon Kinesis stream. Each stream can have up to 10 tags | Tagging | stream* |  |
CreateStream | Grants permission to create a Amazon Kinesis stream | Write | stream* |  |
DecreaseStreamRetentionPeriod | Grants permission to decrease the stream's retention period, which is the length of time data records are accessible after they are added to the stream | Write | stream* |  |
DeleteResourcePolicy | Grants permission to delete a resource policy associated with a specified stream or consumer | Write | consumer* |  |
stream* |  |
DeleteStream | Grants permission to delete a stream and all its shards and data | Write | stream* |  |
DeregisterStreamConsumer | Grants permission to deregister a stream consumer with a Kinesis data stream | Write | consumer* |  |
DescribeLimits | Grants permission to describe the shard limits and usage for the account | Read |  |  |
DescribeStream | Grants permission to describe the specified stream | Read | stream* |  |
DescribeStreamConsumer | Grants permission to get the description of a registered stream consumer | Read | consumer* |  |
DescribeStreamSummary | Grants permission to provide a summarized description of the specified Kinesis data stream without the shard list | Read | stream* |  |
DisableEnhancedMonitoring | Grants permission to disables enhanced monitoring | Write |  |  |
EnableEnhancedMonitoring | Grants permission to enable enhanced Kinesis data stream monitoring for shard-level metrics | Write |  |  |
GetRecords | Grants permission to get data records from a shard | Read | stream* |  |
GetResourcePolicy | Grants permission to get a resource policy associated with a specified stream or consumer | Read | consumer* |  |
stream* |  |
GetShardIterator | Grants permission to get a shard iterator. A shard iterator expires five minutes after it is returned to the requester | Read | stream* |  |
IncreaseStreamRetentionPeriod | Grants permission to increase the stream's retention period, which is the length of time data records are accessible after they are added to the stream | Write | stream* |  |
ListShards | Grants permission to list the shards in a stream and provides information about each shard | List | stream* |  |
ListStreamConsumers | Grants permission to list the stream consumers registered to receive data from a Kinesis stream using enhanced fan-out, and provides information about each consumer | List | stream* |  |
ListStreams | Grants permission to list your streams | List |  |  |
ListTagsForStream | Grants permission to list the tags for the specified Amazon Kinesis stream | Read | stream* |  |
MergeShards | Grants permission to merge two adjacent shards in a stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data | Write | stream* |  |
PutRecord | Grants permission to write a single data record from a producer into an Amazon Kinesis stream | Write | stream* |  |
PutRecords | Grants permission to write multiple data records from a producer into an Amazon Kinesis stream in a single call (also referred to as a PutRecords request) | Write | stream* |  |
PutResourcePolicy | Grants permission to attach a resource policy to a specified stream or consumer | Write | consumer* |  |
stream* |  |
RegisterStreamConsumer | Grants permission to register a stream consumer with a Kinesis data stream | Write | stream* |  |
RemoveTagsFromStream | Grants permission to remove tags from the specified Kinesis data stream. Removed tags are deleted and cannot be recovered after this operation successfully completes | Tagging | stream* |  |
SplitShard | Grants permission to split a shard into two new shards in the Kinesis data stream, to increase the stream's capacity to ingest and transport data | Write | stream* |  |
StartStreamEncryption | Grants permission to enable or update server-side encryption using an AWS KMS key for a specified stream | Write | kmsKey* |  |
stream* |  |
StopStreamEncryption | Grants permission to disable server-side encryption for a specified stream | Write | kmsKey* |  |
stream* |  |
SubscribeToShard | Grants permission to listen to a specific shard with enhanced fan-out | Read | consumer* |  |
UpdateShardCount | Grants permission to update the shard count of the specified stream to the specified number of shards | Write |  |  |
UpdateStreamMode | Grants permission to update the capacity mode of the data stream | Write |  |  |

## Resource types defined by Amazon Kinesis Data Streams

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
stream | `arn:$ { Partition}:kinesis:$ { Region}:$ { Account}:stream/$ { StreamName}` |
consumer | `arn:$ { Partition}:kinesis:$ { Region}:$ { Account}:$ { StreamType}/$ { StreamName}/consumer/$ { ConsumerName}:$ { ConsumerCreationTimpstamp}` |
kmsKey | `arn:$ { Partition}:kms:$ { Region}:$ { Account}:key/$ { KeyId}` |

## Condition keys for Amazon Kinesis Data Streams

Kinesis has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.